@@ -81,7 +81,7 @@ if(margin2 == "GU"){
 }
 
 
-if(margin2 == "GA"){
+if(margin2 %in% c("GA")){
 
  sigma2    <- ifelse(sigma2 < 0.006, 0.006, sigma2)
 
@@ -91,6 +91,27 @@ if(margin2 == "GA"){
     
     }
     
+ 
+#if(margin2 %in% c("ZAGA")){
+#
+#
+#
+#pdf2 <- ifelse(y2 == 0, nu, pdf2 )      
+#                   
+#p2   <- ifelse(y2 == 0, nu, p2)
+#
+#
+##pdf2 <- ifelse(y2 == 0, nu, (1 - nu) * pdf2 )      
+##                   
+##p2   <- ifelse(y2 == 0, nu, nu + (1 - nu) * p2)
+#
+#
+#    
+#    } 
+    
+    
+    
+    
     
     
 
